summaryrefslogtreecommitdiff
path: root/networkx/classes/function.py
diff options
context:
space:
mode:
Diffstat (limited to 'networkx/classes/function.py')
-rw-r--r--networkx/classes/function.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/networkx/classes/function.py b/networkx/classes/function.py
index 61cead31..6b9027fc 100644
--- a/networkx/classes/function.py
+++ b/networkx/classes/function.py
@@ -1288,8 +1288,8 @@ def path_weight(G, path, weight):
Returns
-------
- cost: int
- A integer representing the total cost with respect to the
+ cost: int or float
+ An integer or a float representing the total cost with respect to the
specified weight of the specified path
Raises